djmessenger.tests package — djmessenger 1.1.0 documentation

# djmessenger.tests package

## Submodules

## djmessenger.tests.test_i18n module

class `djmessenger.tests.test_i18n.` `TestI18N`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  `test_basic`()

## djmessenger.tests.test_models module

class `djmessenger.tests.test_models.` `TestGreetings`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  `test_add_second_should_fail`()
  `test_basic`()

## djmessenger.tests.test_receiving module

class `djmessenger.tests.test_receiving.` `TestMessaging`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Sometimes these tests might fail, but I suspect it is an issue with deepdiff library because it is intermittent, most of the times all tests passed

  `test_callback_type_check`()
  `test_message_received`()
  `test_read_json`()

`djmessenger.tests.test_receiving.` `get_sample_path`(callback_type)

## djmessenger.tests.test_routing module

class `djmessenger.tests.test_routing.` `TestRouter`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  `test_deserialization`()

## djmessenger.tests.test_serializable module

class `djmessenger.tests.test_serializable.` `ChildClass1`

  Bases: `djmessenger.utils.serializable.Serializable`

  `excludes` = ['_hidden1']

class `djmessenger.tests.test_serializable.` `ChildClass2`

  Bases: `djmessenger.tests.test_serializable.ChildClass1`

  `excludes` = ['_hidden2', '_hidden1']

class `djmessenger.tests.test_serializable.` `ParentClass`

  Bases: `djmessenger.utils.serializable.Serializable`

  `custom_obj_map` = {'attr1': [<class 'djmessenger.tests.test_serializable.ChildClass1'>, <class 'object'>], 'attr2': [<class 'djmessenger.tests.test_serializable.ChildClass2'>, <class 'object'>]}
  `excludes` = ['_ignore']

class `djmessenger.tests.test_serializable.` `ParentClass2`

  Bases: `djmessenger.utils.serializable.Serializable`

  `custom_obj_map` = {'attr1': [<class 'djmessenger.tests.test_serializable.ParentClass'>, <class 'object'>], 'attr2': [<class 'djmessenger.tests.test_serializable.ChildClass1'>, <class 'object'>], 'attr3': [<class 'djmessenger.tests.test_serializable.ChildClass2'>, <class 'list'>]}

class `djmessenger.tests.test_serializable.` `TestSerializer`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `test_basic`()
  `test_json`()
  `test_obj_map`()
  `test_parent_class`()
  `test_subclass`()
  `test_write_read`()

## Module contents